package com.persagy.ems.pojo.wz;

import java.util.Date;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.persagy.core.annotation.Column;
import com.persagy.core.annotation.Dimension;
import com.persagy.core.annotation.Entity;
import com.persagy.core.annotation.Index;
import com.persagy.core.annotation.Table;
import com.persagy.core.enumeration.Schema;
import com.persagy.core.mvc.pojo.BusinessObject;

/**
 * 日天气数据
 */
@Dimension
@Entity(name = "DayPredictRecord")
@Table(name = "t_day_predict15", comment = "日天气数据", schema = Schema.EMS, indexes = {
		@Index(columns = {"c_day_time", "c_city_Id"}, unique = true),
		@Index(columns = {"c_city_Id"})})
public class DayPredictRecord extends BusinessObject {
	private static final long serialVersionUID = -8754374697346443026L;

	@Column(order = 10, name = "c_city_Id", length = 40, nullable = false, comment = "城市ID")
	@JsonProperty("cityId")
	private String cityId;

	@Column(order = 20, name = "c_day_time", length = 0, nullable = false, comment = "日时间")
	@JsonProperty("dayTime")
	private Date dayTime;
	
	@Column(order = 30, name = "c_update_time", length = 0, nullable = false, comment = "数据更新时间")
	@JsonProperty("updateTime")
	private Date updateTime;
	
	@Column(order = 40, name = "c_text_day", length = 20, nullable = true, comment = "白天天气现象文字")
	@JsonProperty("text_day")
	private String text_day;

	@Column(order = 50, name = "c_code_day", length = 10, nullable = true, comment = "白天天气现象代码")
	@JsonProperty("code_day")
	private String code_day;

	@Column(order = 60, name = "c_text_night", length = 20, nullable = true, comment = "晚间天气现象文字")
	@JsonProperty("text_night")
	private String text_night;

	@Column(order = 70, name = "c_code_night", length = 10, nullable = true, comment = "晚间天气现象代码")
	@JsonProperty("code_night")
	private String code_night;

	@Column(order = 80, name = "c_high", length = 10, nullable = true, comment = "当天最高温度")
	@JsonProperty("high")
	private String high;

	@Column(order = 90, name = "c_low", length = 10, nullable = true, comment = "当天最低温度")
	@JsonProperty("low")
	private String low;

	@Column(order = 100, name = "c_precip", length = 10, nullable = true, comment = "降水概率，范围0~100，单位百分比（目前仅支持国外城市）")
	@JsonProperty("precip")
	private String precip;
	
	@Column(order = 110, name = "c_wind_direction", length = 20, nullable = true, comment = "风向文字")
	@JsonProperty("wind_direction")
	private String wind_direction;
	
	@Column(order = 120, name = "c_wind_direction_degree", length = 10, nullable = true, comment = "风向角度，范围0~360，0为正北，90为正东，180为正南，270为正西")
	@JsonProperty("wind_direction_degree")
	private String wind_direction_degree;
	
	@Column(order = 130, name = "c_wind_speed", length = 10, nullable = true, comment = "风速")
	@JsonProperty("wind_speed")
	private String wind_speed;
	
	@Column(order = 140, name = "c_wind_scale", length = 10, nullable = true, comment = "风力等级")
	@JsonProperty("wind_scale")
	private String wind_scale;
	
	@Column(order = 150, name = "c_rainfall", length = 10, nullable = true, comment = "云量，范围0~100，天空被云覆盖的百分比")
	@JsonProperty("rainfall")
	private String rainfall;
	
	@Column(order = 160, name = "c_humidity", length = 10, nullable = true, comment = "云量，范围0~100，天空被云覆盖的百分比")
	@JsonProperty("humidity")
	private String humidity;
	
	@Column(order=170, name="c_last_update", length=0, nullable=true, comment="数据最新更新时间")
	@JsonProperty("lastUpdate")
	private Date lastUpdate;

	public String getCityId() {
		return cityId;
	}

	public void setCityId(String cityId) {
		this.cityId = cityId;
	}

	public Date getDayTime() {
		return dayTime;
	}

	public void setDayTime(Date dayTime) {
		this.dayTime = dayTime;
	}

	public Date getUpdateTime() {
		return updateTime;
	}

	public void setUpdateTime(Date updateTime) {
		this.updateTime = updateTime;
	}

	public String getText_day() {
		return text_day;
	}

	public void setText_day(String text_day) {
		this.text_day = text_day;
	}

	public String getCode_day() {
		return code_day;
	}

	public void setCode_day(String code_day) {
		this.code_day = code_day;
	}

	public String getText_night() {
		return text_night;
	}

	public void setText_night(String text_night) {
		this.text_night = text_night;
	}

	public String getCode_night() {
		return code_night;
	}

	public void setCode_night(String code_night) {
		this.code_night = code_night;
	}

	public String getHigh() {
		return high;
	}

	public void setHigh(String high) {
		this.high = high;
	}

	public String getLow() {
		return low;
	}

	public void setLow(String low) {
		this.low = low;
	}

	public String getPrecip() {
		return precip;
	}

	public void setPrecip(String precip) {
		this.precip = precip;
	}

	public String getWind_direction() {
		return wind_direction;
	}

	public void setWind_direction(String wind_direction) {
		this.wind_direction = wind_direction;
	}

	public String getWind_direction_degree() {
		return wind_direction_degree;
	}

	public void setWind_direction_degree(String wind_direction_degree) {
		this.wind_direction_degree = wind_direction_degree;
	}

	public String getWind_speed() {
		return wind_speed;
	}

	public void setWind_speed(String wind_speed) {
		this.wind_speed = wind_speed;
	}

	public String getWind_scale() {
		return wind_scale;
	}

	public void setWind_scale(String wind_scale) {
		this.wind_scale = wind_scale;
	}

	public String getRainfall() {
		return rainfall;
	}

	public void setRainfall(String rainfall) {
		this.rainfall = rainfall;
	}

	public String getHumidity() {
		return humidity;
	}

	public void setHumidity(String humidity) {
		this.humidity = humidity;
	}

	public Date getLastUpdate() {
		return lastUpdate;
	}

	public void setLastUpdate(Date lastUpdate) {
		this.lastUpdate = lastUpdate;
	}
}
