package com.persagy.ems.pojo.wz;

import com.fasterxml.jackson.annotation.JsonProperty;
import com.persagy.core.annotation.Column;
import com.persagy.core.annotation.Dimension;
import com.persagy.core.annotation.Entity;
import com.persagy.core.annotation.Index;
import com.persagy.core.annotation.Table;
import com.persagy.core.enumeration.Schema;
import com.persagy.core.enumeration.EMSDimension;
import com.persagy.core.mvc.pojo.BusinessObject;
import java.util.Date;

@Dimension(dimension = EMSDimension.Building)
@Entity(name = "DayStaticMoreRecord")
@Table(name = "t_day_static_more", comment = "天气数据统计", schema = Schema.EMS, indexes = {
		@Index(columns = { "c_city_Id", "c_day_time" }, unique = true),
		@Index(columns = { "c_day_time", "c_city_Id" }) })
public class DayStaticMoreRecord extends BusinessObject {
	private static final long serialVersionUID = 3236557856634985217L;
	
	@JsonProperty("cityId")
	@Column(order = 2, name = "c_city_Id", length = 40, nullable = false, comment = "城市编码")
	private String cityId;
	@JsonProperty("dayTime")
	@Column(order = 3, name = "c_day_time", length = 0, nullable = false, comment = "日开始时间")
	private Date dayTime;
	@JsonProperty("updateTime")
	@Column(order = 3, name = "c_update_time", length = 0, nullable = false, comment = "数据保存时间")
	private Date updateTime;
	@Column(order = 4, name = "c_avg_temp", length = 40, scale = 1, nullable = true, comment = "日平均温度，单位c摄氏度")
	@JsonProperty("avgTemp")
	private Double avgTemp;
	@Column(order = 5, name = "c_avg_wind_speed", length = 40, scale = 1, nullable = true, comment = "日平均风速，单位km/h")
	@JsonProperty("avgWindSpeed")
	private Double avgWindSpeed;
	@Column(order = 6, name = "c_avg_humidity", length = 40, scale = 1, nullable = true, comment = "日平均相对湿度，0~100，单位百分比")
	@JsonProperty("avgHumidity")
	private Double avgHumidity;
	@Column(order = 7, name = "c_avg_pressure", length = 40, scale = 1, nullable = true, comment = "日平均气压，单位mb百帕")
	@JsonProperty("avgPressure")
	private Double avgPressure;
	@Column(order = 8, name = "c_avg_visibility", length = 40, scale = 1, nullable = true, comment = "日平均能见度，单位为km公里")
	@JsonProperty("avgVisibility")
	private Double avgVisibility;
	@Column(order = 9, name = "c_info", length = 255, nullable = true, comment = "附加信息，存放json格式字符串")
	@JsonProperty("info")
	private String info;
	
	public String getCityId() {
		return cityId;
	}
	public void setCityId(String cityId) {
		this.cityId = cityId;
	}
	public Date getDayTime() {
		return dayTime;
	}
	public void setDayTime(Date dayTime) {
		this.dayTime = dayTime;
	}
	public Date getUpdateTime() {
		return updateTime;
	}
	public void setUpdateTime(Date updateTime) {
		this.updateTime = updateTime;
	}
	public Double getAvgTemp() {
		return avgTemp;
	}
	public void setAvgTemp(Double avgTemp) {
		this.avgTemp = avgTemp;
	}
	public Double getAvgWindSpeed() {
		return avgWindSpeed;
	}
	public void setAvgWindSpeed(Double avgWindSpeed) {
		this.avgWindSpeed = avgWindSpeed;
	}
	public Double getAvgHumidity() {
		return avgHumidity;
	}
	public void setAvgHumidity(Double avgHumidity) {
		this.avgHumidity = avgHumidity;
	}
	public Double getAvgPressure() {
		return avgPressure;
	}
	public void setAvgPressure(Double avgPressure) {
		this.avgPressure = avgPressure;
	}
	public Double getAvgVisibility() {
		return avgVisibility;
	}
	public void setAvgVisibility(Double avgVisibility) {
		this.avgVisibility = avgVisibility;
	}
	public String getInfo() {
		return info;
	}
	public void setInfo(String info) {
		this.info = info;
	}
	
}
