package com.persagy.functions.weather.business.v2020.maintain;

import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.persagy.core.service.BaseBusinessService;
import com.persagy.core.service.BusinessService;
import com.persagy.framework.util.DateUtils;
import com.persagy.functions.weather.constant.Const;
import com.persagy.functions.weather.service.DayStaticService;
import com.persagy.functions.weather.service.HourRecordService;
import com.persagy.functions.weather.thread.HourToDayAvgDataComputeThread;

/**
 * 通过日小时数据来计算得出日统计均值数据 
 */
@Service("HourToDayAvgData")
@SuppressWarnings({"unchecked","rawtypes" })
public class HourToDayAvgData extends BaseBusinessService<Map> implements BusinessService {
	@Resource
	private HourRecordService hourDataService;
	
	@Resource
	private DayStaticService dayStaticService;
	
	@Override
	public void handle(Map dto, List content) throws Exception {
		// ALL，所有城市
		String cityId = (String) dto.get("cityId");
		
		// yyyy-MM-dd
		String startDay = (String) dto.get("startDay");
		String endDay = (String) dto.get("endDay");
		
		if(cityId == null || startDay == null || endDay == null) {
			throw new Exception(Const.ErrorTag.paramMis);
		}
		
		Date fromDay = DateUtils.str2Date(startDay, DateUtils.SDF_DAY);
		Date toDay = DateUtils.str2Date(endDay, DateUtils.SDF_DAY);
		
		new Thread(new HourToDayAvgDataComputeThread(hourDataService, dayStaticService, 
				cityId, fromDay, toDay)).start();
		
		content.add("Task start running...");
	}
	
}
